#
# This is a Shiny web application. Assuming you've opened the app in RStudio, you can run it by clicking
# the 'Run App' button above.
#

library(shiny)
library(shinythemes)

# Define UI for application
ui <- navbarPage(
  theme = shinytheme("sandstone"),
  title = "QIBs in Clinical Trials",
  
  tabPanel(
    title = "About app",
    tags$p("This R Shiny application was developed to execute some of the calculations discussed in the following paper:"),
    tags$h5("Statistical Considerations for Planning a Clinical Trial with Quantitative Imaging Biomarkers", class='text-info'),
    tags$br(),
    tags$h5(tags$b("SAMPLE SIZE")),
    tags$p("When a quantitative imaging biomarker (QIB) will be involved in one of the scientific objectives of a clinical trial, 
           this app allows users to adjust the required sample size to account for the measurement error in the QIB. The QIB may be 
           measured at one or two time points."),
    tags$br(),
    tags$h5(tags$b("DECISION CRITERIA")),
    tags$p("When a quantitative imaging biomarker (QIB)  will be used as an integral biomarker in a clinical trial (for example to 
           determine a subject's eligibility), the app allows users to adjust the decision criteria to account for the measurement 
           error in the QIB. The QIB may be measured at one or two time points.")
  ),
  
  tabPanel(
    title = "Sample size",
    tags$h3("QIB measured at 1 time point", class='text-danger'),
    tags$h5(tags$b("GOAL:"), "Account for the measurement error in a QIB when calculating the sample size needed to..."),
    HTML("<ul style='list-style-type:none'>
          <li>...construct a confidence interval for the QIB's area under the ROC curve. <a id='show_ex1' href='#' class='action-button'>Example</a>.</li>
          <li>...assess a hypothesis involving the QIB's area under the ROC curve. <a id='show_ex2' href='#' class='action-button'>Example</a>.</li>
          <li>...estimate the association between the QIB and a patient outcome. <a id='show_ex3' href='#' class='action-button'>Example</a>.</li>
          <li>...assess a hypothesis where the QIB is considered an endpoint. <a id='show_ex4' href='#' class='action-button'>Example</a>.</li>
          </ul>"),
    tags$br(),
    sidebarLayout(
      sidebarPanel(
        width = 8,
        tags$h4("INPUT:", class='text-info'),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_Nx", label = HTML("<i>N<sub>X</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The sample size needed for the desired power if the true biomarker values were used in the trial (i.e. if there was no measurement error).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_B1", label = HTML("<i>&beta;<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The proportional bias of the QIB measurement method. This is the slope of a regression line of the true values (x-axis) vs. 
                     the QIB measurements (y-axis).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_var.b", label = HTML("<i>&sigma;<sub>b</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The variability in the true biomarker value across subjects in the population.")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_var.e", label = HTML("<i>&sigma;<sub>e</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The variability in the measured QIB value when measuring a subject over a short period of time (so that no true change has occurred)."),
            actionLink("show_help_t1_1a", HTML("Does <i>&sigma;<sub>e</sub><sup>2</sup></i> represent repeatability or reproducibility?")),
            tags$br(),
            actionLink("show_help_t1_1b", HTML("What if <i>&sigma;<sub>e</sub><sup>2</sup></i> depends on the true biomarker value?"))
          )
        ),
        tags$br(),
        actionButton(inputId = "t1_calc", label = "CALCULATE", width = "100%", class="btn btn-info")
      ),
      mainPanel(
        width = 4,
        tags$br(),
        tags$h4("SAMPLE SIZE ESTIMATE:", class='text-info'),
        tags$blockquote(tags$i(textOutput("t1_n"))),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s):"),
        img(src='eq1.png', align = "center", width = 150, height = 68)
      )
    ),

    tags$hr(),

    tags$h3("QIB measured at 2 time points", class='text-danger'),
    tags$h5(tags$b("GOAL:"), "Account for the measurement error in a QIB when calculating the sample size needed to..."),
    HTML("<ul style='list-style-type:none'>
         <li>...estimate the association between the change in a QIB over time and a patient outcome. <a id='show_ex5' href='#' class='action-button'>Example</a>.</li>
         <li>...assess a hypothesis where the change in a QIB over time is considered an endpoint. <a id='show_ex6' href='#' class='action-button'>Example</a>.</li>
         </ul>"),
    tags$br(),
    sidebarLayout(
      sidebarPanel(
        width = 8,
        tags$h4("INPUT:", class='text-info'),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_Nx.2", label = HTML("<i>N<sub>X</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The sample size needed for the desired power if the true biomarker values were used in the trial (i.e. if there was no measurement error).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_B1.2", label = HTML("<i>&beta;<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The proportional bias of the QIB measurement method. This is the slope of a regression line of the true values (x-axis) vs.
                     the QIB measurements (y-axis).")
            )
          ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t1_var.b.2", label = HTML("<i>&sigma;<sub>b</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The variability in the true biomarker value across subjects in the population.")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput("t1_var.e1.2", label = HTML("<i>&sigma;<sub>e1</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("At time point 1, the variability in the measured QIB value when measuring a subject over a short period of time
                     (so that no true change has occurred).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput("t1_var.e2.2", label = HTML("<i>&sigma;<sub>e2</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("At time point 2, the variability in the measured QIB value when measuring a subject over a short period of time
                     (so that no true change has occurred)."),
            actionLink("show_help_t1_2a", HTML("Do <i>&sigma;<sub>e1</sub><sup>2</sup></i> and <i>&sigma;<sub>e2</sub><sup>2</sup></i> represent repeatability or reproducibility?")),
            tags$br(),
            actionLink("show_help_t1_2b", HTML("What if <i>&sigma;<sub>e1</sub><sup>2</sup></i> and <i>&sigma;<sub>e2</sub><sup>2</sup></i> depend on the true biomarker value?"))
            )
          ),
        tags$br(),
        actionButton(inputId = "t1_calc.2", label = "CALCULATE", width = "100%", class="btn btn-info")
      ),
      mainPanel(
        width = 4,
        tags$br(),
        tags$h4("SAMPLE SIZE ESTIMATE:", class='text-info'),
        tags$blockquote(tags$i(textOutput("t1_n.2"))),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s):"),
        img(src='eq2.png', align = "center", width = 200, height = 68)
      )
    )
  ),
  
  tabPanel(
    title = "Decision criteria",
    tags$h3("QIB measured at 1 time point", class='text-danger'),
    tags$p(HTML("<b>GOAL:</b> Use a QIB as an integral biomarker and account for the measurement error in the QIB. 
                <a id='show_ex7' href='#' class='action-button'>Example</a>.")),
    tags$br(),
    sidebarLayout(
      sidebarPanel(
        width = 8,
        tags$h4("INPUT:", class='text-info'),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_z1", label = HTML("<i>z<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=4,
            "<  true biomarker  <"
          ),
          column(
            width=4,
            textInput(inputId = "t2_z2", label = HTML("<i>z<sub>2</sub></i>"), value = NA)
          )
        ),
        helpText("Decision criteria before considering measurement error.  If unbounded on one end, leave", HTML("<i>z<sub>1</sub></i>"), "or",
                 HTML("<i>z<sub>2</sub></i>"), "blank (e.g. if a patient is eligible if his QIB value is less than 5, enter 5 for", HTML("<i>z<sub>2</sub></i>"), 
                 "and leave", HTML("<i>z<sub>1</sub></i>"), "blank)."),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_conf", label = HTML("<i>1 - &alpha;</i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("Desired confidence level for the decision involving the QIB as an integral biomarker.")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_B0", label = HTML("<i>&beta;<sub>0</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The fixed bias of the QIB measurement method.")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_B1", label = HTML("<i>&beta;<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The proportional bias of the QIB measurement method. This is the slope of a regression line of the true values (x-axis) vs. 
                     the QIB measurements (y-axis).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_var.e", label = HTML("<i>&sigma;<sub>e</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The variability in the measured QIB value when measuring a subject over a short period of time (so that no true change has occurred)."),
            actionLink("show_help_t2_1a", HTML("Does <i>&sigma;<sub>e</sub><sup>2</sup></i> represent repeatability or reproducibility?")),
            tags$br(),
            actionLink("show_help_t2_1b", HTML("What if <i>&sigma;<sub>e</sub><sup>2</sup></i> depends on the true biomarker value?"))
          )
        ),
        tags$br(),
        actionButton(inputId = "t2_calc", label = "CALCULATE", width = "100%", class="btn btn-info")
      ),
      mainPanel(
        width = 4,
        tags$br(),
        tags$h4("ADJUSTED DECISION CRITERIA:", class='text-info'),
        tags$blockquote(tags$i(textOutput("t2_d"))),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s) when one-sided:"),
        img(src='eq3_lo.png', align = "center", width = 230, height = 38),
        img(src='eq3_up.png', align = "center", width = 230, height = 35),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s) when two-sided:"),
        img(src='eq4_lo.png', align = "center", width = 230, height = 38),
        img(src='eq4_up.png', align = "center", width = 235, height = 38)
      )
    ),
    
    tags$hr(),
    
    tags$h3("QIB measured at 2 time points", class='text-danger'),
    tags$p(HTML("<b>GOAL:</b> Use the change in a QIB over time as an integral biomarker and account for the measurement error in the QIB. 
                <a id='show_ex8' href='#' class='action-button'>Example</a>.")),
    tags$br(),
    sidebarLayout(
      sidebarPanel(
        width = 8,
        tags$h4("INPUT:", class='text-info'),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_z1.2", label = HTML("<i>z<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=4,
            HTML("&lt; &Delta; in true biomarker &lt;")
          ),
          column(
            width=4,
            textInput(inputId = "t2_z2.2", label = HTML("<i>z<sub>2</sub></i>"), value = NA)
          )
        ),
        helpText("Decision criteria before considering measurement error.  If unbounded on one end, leave", HTML("<i>z<sub>1</sub></i>"), "or",
                 HTML("<i>z<sub>2</sub></i>"), "blank (e.g. if a patient is eligible if the change in his QIB value is less than 5, enter 5 for", 
                 HTML("<i>z<sub>2</sub></i>"), "and leave", HTML("<i>z<sub>1</sub></i>"), "blank)."),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_conf.2", label = HTML("<i>1 - &alpha;</i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("Desired confidence level for the decision involving the QIB as an integral biomarker.")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_B1.2", label = HTML("<i>&beta;<sub>1</sub></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The proportional bias of the QIB measurement method. This is the slope of a regression line of the true values (x-axis) vs. 
                     the QIB measurements (y-axis).")
          )
        ),
        fluidRow(
          column(
            width=4,
            textInput(inputId = "t2_var.e.2", label = HTML("<i>&sigma;<sub>e</sub><sup>2</sup></i>"), value = NA)
          ),
          column(
            width=8,
            tags$br(),
            helpText("The variability in the measured QIB value when measuring a subject over a short period of time (so that no true change has occurred)."),
            actionLink("show_help_t2_2a", HTML("Does <i>&sigma;<sub>e</sub><sup>2</sup></i> represent repeatability or reproducibility?")),
            tags$br(),
            actionLink("show_help_t2_2b", HTML("What if <i>&sigma;<sub>e</sub><sup>2</sup></i> depends on the true biomarker value?"))
          )
        ),
        tags$br(),
        actionButton(inputId = "t2_calc.2", label = "CALCULATE", width = "100%", class="btn btn-info")
      ),
      mainPanel(
        width = 4,
        tags$br(),
        tags$h4("ADJUSTED DECISION CRITERIA:", class='text-info'),
        tags$blockquote(tags$i(htmlOutput("t2_d.2"))),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s) when one-sided:"),
        img(src='eq5_lo.png', align = "center", width = 220, height = 36),
        img(src='eq5_up.png', align = "center", width = 222, height = 36),
        tags$br(),
        tags$br(),
        tags$h5("Formula(s) when two-sided:"),
        img(src='eq6_lo.png', align = "center", width = 220, height = 36),
        img(src='eq6_up.png', align = "center", width = 222, height = 37)
      )
    )
  )
)


# Define server logic 
server <- function(input, output) {
  
  # CALCULATE BUTTONS
  t1_n <- eventReactive(input$t1_calc, {
    ceiling((as.numeric(input$t1_Nx) * (as.numeric(input$t1_B1)^2 * as.numeric(input$t1_var.b) + as.numeric(input$t1_var.e))) / 
              (as.numeric(input$t1_B1)^2 * as.numeric(input$t1_var.b)))
  })
  
  output$t1_n <- renderText({ 
    paste("n =", t1_n())
  })
  
  t1_n.2 <- eventReactive(input$t1_calc.2, {
    ceiling((as.numeric(input$t1_Nx.2) * (2*as.numeric(input$t1_B1.2)^2 * as.numeric(input$t1_var.b.2) + as.numeric(input$t1_var.e1.2) + as.numeric(input$t1_var.e2.2))) / 
              (2*as.numeric(input$t1_B1.2)^2 * as.numeric(input$t1_var.b.2)))
  })
  
  output$t1_n.2 <- renderText({ 
    paste("n =", t1_n.2())
  })
  
  t2_d <- eventReactive(input$t2_calc, {
    if(input$t2_z1!="" & input$t2_z2!="") {
      z_alpha <- qnorm(p = 0.5 + as.numeric(input$t2_conf)/2)
      t2_d_lo <- (as.numeric(input$t2_z1) + as.numeric(input$t2_B0) + z_alpha*sqrt(as.numeric(input$t2_var.e))) / as.numeric(input$t2_B1)
      t2_d_up <- (as.numeric(input$t2_z2) + as.numeric(input$t2_B0) - z_alpha*sqrt(as.numeric(input$t2_var.e))) / as.numeric(input$t2_B1)
      paste(format(t2_d_lo, digits = 2), "< measured biomarker <", format(t2_d_up, digits = 2))
    } else
    if(input$t2_z1!="") {
      z_alpha <- qnorm(p = as.numeric(input$t2_conf))
      t2_d_lo <- (as.numeric(input$t2_z1) + as.numeric(input$t2_B0) + z_alpha*sqrt(as.numeric(input$t2_var.e))) / as.numeric(input$t2_B1)
      paste(format(t2_d_lo, digits = 2), "< measured biomarker")
    } else
    if(input$t2_z2!="") {
      z_alpha <- qnorm(p = as.numeric(input$t2_conf))
      t2_d_up <- (as.numeric(input$t2_z2) + as.numeric(input$t2_B0) - z_alpha*sqrt(as.numeric(input$t2_var.e))) / as.numeric(input$t2_B1)
      paste("measured biomarker <", format(t2_d_up, digits = 2))
    }
  })
  
  output$t2_d <- renderText({ 
    t2_d()
  })
  
  t2_d.2 <- eventReactive(input$t2_calc.2, {
    if(input$t2_z1.2!="" & input$t2_z2.2!="") {
      z_alpha <- qnorm(p = 0.5 + as.numeric(input$t2_conf.2)/2)
      t2_d_lo <- (as.numeric(input$t2_z1.2) + z_alpha*sqrt(2)*sqrt(as.numeric(input$t2_var.e.2))) / as.numeric(input$t2_B1.2)
      t2_d_up <- (as.numeric(input$t2_z2.2) - z_alpha*sqrt(2)*sqrt(as.numeric(input$t2_var.e.2))) / as.numeric(input$t2_B1.2)
      paste(format(t2_d_lo, digits = 2), "&lt; &Delta; in measured biomarker &lt;", format(t2_d_up, digits = 2))
    } else
      if(input$t2_z1.2!="") {
        z_alpha <- qnorm(p = as.numeric(input$t2_conf))
        t2_d_lo <- (as.numeric(input$t2_z1.2) + z_alpha*sqrt(2)*sqrt(as.numeric(input$t2_var.e.2))) / as.numeric(input$t2_B1.2)
        paste(format(t2_d_lo, digits = 2), "&lt; &Delta; in measured biomarker")
      } else
        if(input$t2_z2.2!="") {
          z_alpha <- qnorm(p = as.numeric(input$t2_conf))
          t2_d_up <- (as.numeric(input$t2_z2.2) - z_alpha*sqrt(2)*sqrt(as.numeric(input$t2_var.e.2))) / as.numeric(input$t2_B1.2)
          paste("&Delta; in measured biomarker &lt;", format(t2_d_up, digits = 2))
        }
  })
  
  output$t2_d.2 <- renderUI({ 
    HTML(t2_d.2())
  })
  

  # HELP BUTTONS
  HelpText1a <- "If the subjects in this study will be imaged under the same conditions (e.g. at the same center, using the same scanner and image 
                analysis software, with interpretations provided by the same reader, etc.), then this variance represents the repeatability of the 
                QIB measurement. If the subjects will be imaged under different conditions, the variance should be higher because it now represents 
                the reproducibility of the QIB measurement."
  
  HelpText2a <- "If a given subject will be imaged under the same conditions at both time points (e.g. at the same center, using the same scanner and
                  image analysis software, with interpretations provided by the same reader, etc.), then these variances represent the repeatability of
                  the QIB measurement.  If a given subject will be imaged under one condition at the first time point and a different condition at the
                  second time point, these variances should be higher because they now represent the reproducibility of the QIB measurement."
  
  HelpText2a_alt <- "If a given subject will be imaged under the same conditions at both time points (e.g. at the same center, using the same scanner and
                    image analysis software, with interpretations provided by the same reader, etc.), then this variance represents the repeatability of
                    the QIB measurement.  If a given subject will be imaged under one condition at the first time point and a different condition at the
                    second time point, this variance should be higher because it now represents the reproducibility of the QIB measurement."

  HelpText1b <- "If the within-subject variability in the measurement process is constant no matter what the true biomarker value is, you can simply use
                the square of the within-subject standard deviation of the QIB measurements. However, if the within-subject variability in the measurement
                process depends on the true biomarker value (for example, if there is more variability when measuring high QIB values), then we suggest
                using the square of the product of the within-subject coefficient of variation (CV) and the mean QIB value in the population (i.e. [CV * Y_bar]^2)."

  HelpText2b <- HelpText1b
  
  observeEvent(input$show_help_t1_1a, {
    showModal(modalDialog(
      title = "Repeatability or reproducibility?",
      HelpText1a,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t1_1b, {
    showModal(modalDialog(
      title = "What if this variance depends on the true value?",
      HelpText1b,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t1_2a, {
    showModal(modalDialog(
      title = "Repeatability or reproducibility?",
      HelpText2a,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t1_2b, {
    showModal(modalDialog(
      title = "What if this variance depends on the true value?",
      HelpText2b,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t2_1a, {
    showModal(modalDialog(
      title = "Repeatability or reproducibility?",
      HelpText1a,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t2_1b, {
    showModal(modalDialog(
      title = "What if this variance depends on the true value?",
      HelpText1b,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t2_2a, {
    showModal(modalDialog(
      title = "Repeatability or reproducibility?",
      HelpText2a_alt,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_help_t2_2b, {
    showModal(modalDialog(
      title = "What if this variance depends on the true value?",
      HelpText2b,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  # EXAMPLE BUTTONS
  ExText1 = "Suppose you want to construct a 95% CI for the QIB's ROC area. To determine the required sample size, first compute the sample
             size if there was no measurement error. Then enter this sample size, along with the expected measurement error of the QIB, in the input box 
             and click 'CALCULATE'."
  ExText2 = "Suppose you want to test if the QIB's ROC area differs from a hypothesized value, say theta.  The null hypothesis is that the ROC area equals theta, 
             versus the alternative hypothesis that the ROC area does not equal theta. To determine the required sample size, first compute the sample
             size if there was no measurement error. Then enter this sample size, along with the expected measurement error of the QIB, in the input box 
             and click 'CALCULATE'."
  ExText3 = "Suppose you want to test if subjects' QIB values before treatment predict time until progression. To determine the required sample size, first compute 
             the sample size if there was no measurement error. Then enter this sample size, along with the expected measurement error of the QIB, in the input 
             box and click 'CALCULATE'."
  ExText4 = "Suppose you want to conduct a study where the QIB is considered an intermediate outcome, or possibly a surrogate, for a patient endpoint, e.g. time 
             to progression. To determine sample size, first compute the sample size if there was no measurement error. Then enter this sample size, along with 
             the expected measurement error of the QIB, in the input box and click 'CALCULATE'."
  ExText5 = "Suppose you want to test if the change in a QIB from baseline to several weeks into treatment predicts time until progression. To determine the 
             required sample size, first compute the sample size if there was no measurement error. Then enter this sample size, along with the expected 
             measurement error of the QIB, in the input box and click 'CALCULATE'."
  ExText6 = "Suppose you want to conduct a study where the change in the QIB is considered an intermediate outcome, or possibly a surrogate, for a patient endpoint,
             e.g. time to progression. To determine the required sample size, first compute the sample size if there was no measurement error. Then enter this sample
             size, along with the expected measurement error of the QIB, in the input box and click 'CALCULATE'."
  ExText7 = "Suppose you decide that subjects with QIB values between z1 and z2 will be eligible for your study. Since the QIB is measured with error, different
             values for z1 and z2 are needed that take this measurement error and your desired confidence level into account. To determine the adjusted decision
             criteria, first input the values for z1 and z2 that you would have used if the biomarker was measured without error. Then input your confidence level, 
             along with the expected measurement error of the QIB, in the input box and click 'CALCULATE'."
  ExText8 = "Suppose you will measure the change in subjects' biomarker value from baseline to several weeks after treatment. If patients have a significant change
             over time, their treatment will be revised; otherwise, they will remain on the current treatment plan. You decide that subjects whose biomarker values
             change between z1 and z2 will remain on the current treatment plan. Since the QIB is measured with error, the decision thresholds need to be adjusted 
             to account for any bias and imprecision. To determine the adjusted decision criteria, first input the values for z1 and z2 that you would have used if
             the biomarker was measured without error. Then input your confidence level, along with the expected measurement error of the QIB, in the input box and 
             click 'CALCULATE'."
  
  observeEvent(input$show_ex1, {
    showModal(modalDialog(
      title = "Example",
      ExText1,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex2, {
    showModal(modalDialog(
      title = "Example",
      ExText2,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex3, {
    showModal(modalDialog(
      title = "Example",
      ExText3,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex4, {
    showModal(modalDialog(
      title = "Example",
      ExText4,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex5, {
    showModal(modalDialog(
      title = "Example",
      ExText5,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex6, {
    showModal(modalDialog(
      title = "Example",
      ExText6,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex7, {
    showModal(modalDialog(
      title = "Example",
      ExText7,
      easyClose = TRUE,
      footer = NULL
    ))
  })
  
  observeEvent(input$show_ex8, {
    showModal(modalDialog(
      title = "Example",
      ExText8,
      easyClose = TRUE,
      footer = NULL
    ))
  })

}


# Run the application 
shinyApp(ui = ui, server = server)

